@@ -192,12 +192,18 @@ elsif (ref [] eq ref setting('tacacs')) {
   config->{'tacacs'} = [ @newservers ];
 }
 
-# support unordered dictionary as if it were a single item list
+# support unordered dictionaries as if they were a single item list
+
 if (ref {} eq ref setting('device_identity')) {
   config->{'device_identity'} = [ setting('device_identity') ];
 }
 else { config->{'device_identity'} ||= [] }
 
+if (ref {} eq ref setting('macsuck_no_deviceport')) {
+  config->{'macsuck_no_deviceport'} = [ setting('macsuck_no_deviceport') ];
+}
+else { config->{'macsuck_no_deviceport'} ||= [] }
+
 # copy devices_no and devices_only into others
 foreach my $name (qw/devices_no devices_only
                     discover_no macsuck_no arpnip_no nbtstat_no
